@@ -4,4 +4,4 @@
 #' @docType package
 #' @importFrom stats runif optim
 #' @useDynLib geodist, .registration = TRUE
-NULL
+"_PACKAGE"
